==> thirdparty-service-biz-1.0.31-sources.jar: cn/com/duiba/mq/RocketMqMessageListener.java <==
package cn.com.duiba.mq;


import cn.com.duiba.api.bo.addcredits.AddCreditsMsgDto;
import cn.com.duiba.api.bo.mq.EmailMsg;
import cn.com.duiba.api.bo.subcredits.SubCreditsMsgDto;
import cn.com.duiba.api.bo.virtual.VirtualMsgDto;
import cn.com.duiba.api.tools.GZIPCompressUtil;
import cn.com.duiba.crecord.message.CrecordAsyncHttp;
import cn.com.duiba.mq.dinghandler.SendDingMsgHelper;
import cn.com.duiba.notifycenter.domain.NotifyQueueDO;
import cn.com.duiba.notifycenter.service.NotifyService;
import cn.com.duiba.service.CreditsService;
import cn.com.duiba.service.DevAppTrustConfService;
import cn.com.duiba.service.EmailService;
import cn.com.duiba.thirdparty.dto.NotifyQueueDto;
import cn.com.duiba.thirdparty.mq.msg.NotifyDeveloperMsg;
import cn.com.duiba.thirdparty.mq.msg.ValidatePrizeTagMsg;
import com.alibaba.fastjson.JSONObject;
import org.apache.commons.lang.StringUtils;
import org.apache.rocketmq.client.consumer.listener.ConsumeConcurrentlyContext;
import org.apache.rocketmq.client.consumer.listener.ConsumeConcurrentlyStatus;
import org.apache.rocketmq.client.consumer.listener.MessageListenerConcurrently;
import org.apache.rocketmq.common.message.MessageExt;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.nio.charset.Charset;
import java.util.List;
import java.util.Objects;

/**
 * Created by yansen on 17/5/5.
 */
@Component("bootRocketMqMessageListener")
public class RocketMqMessageListener implements MessageListenerConcurrently {

    private static Logger logger = LoggerFactory.getLogger(RocketMqMessageListener.class);

    @Autowired
    private DevAppTrustConfService devAppTrustConfService;

    @Autowired
    private RocketMQTopicConstant rocketMQTopicConstant;

    @Autowired
    private CrecordAsyncHttp crecordAsyncHttp;

    @Autowired
    private CreditsService creditsService;
    @Autowired
    private EmailService emailService;
    @Autowired
    private NotifyService notifyService;
    @Autowired
    private SendDingMsgHelper sendDingMsgHelper;

    /**
     * It is not recommend to throw exception,rather than returning ConsumeConcurrentlyStatus.RECONSUME_LATER if consumption failure
     *
     * @param msgs    msgs.size() >= 1<br> DefaultMQPushConsumer.consumeMessageBatchMaxSize=1,you can modify here
     * @param context
     * @return The consume status
     */
    @Override
    public ConsumeConcurrentlyStatus consumeMessage(List<org.apache.rocketmq.common.message.MessageExt> msgs, ConsumeConcurrentlyContext context) {
        MessageExt index=null;
        try {
            //经过duiba-spring-boot-starter的内部限制，实际上msgs里只会包含一个消息，但是不排除将来可能会改为多个，而且每个消息的topic都不同
            for (MessageExt message : msgs) {
                if (null==message){
                    if (null!=context&&null!=context.getMessageQueue()){
                        logger.info("消费消息异常,message为空 {}",context.getMessageQueue().getTopic());
                    }else {
                        logger.info("消费消息异常,message为空，队列也为空");
                    }
                    continue;
                }
                index=message;
                String topic = message.getTopic();
                if (!consumePerMessage(message, topic)) {
                    return ConsumeConcurrentlyStatus.RECONSUME_LATER;
                }
            }
        } catch (Exception e) {
            logger.error("消费消息异常,topic:{}, msg:{}",index.getTopic(), JSONObject.toJSONString(SubCreditsMsgDto.decode(index.getBody())), e);
            if(e.getCause() != null){
                logger.error("消费消息异常,cause:{}", e.getCause());
            }
            //发生异常时通常要重新消费，如果在发生特殊异常时你不希望该消息重新消费
            // 则自行加个catch分支，并返回ConsumeConcurrentlyStatus.CONSUME_SUCCESS
            return ConsumeConcurrentlyStatus.RECONSUME_LATER;
        }
        return ConsumeConcurrentlyStatus.CONSUME_SUCCESS;
    }

    private boolean consumePerMessage(MessageExt message, String topic) {
        boolean isConsumed = true;
        //兑换记录同步
        if (Objects.equals(rocketMQTopicConstant.getCrecordRequest(), topic)) {
            String body = new String(message.getBody(), Charset.forName("utf-8"));
            crecordAsyncHttp.asyncSubmit(body);
        } else if (Objects.equals(rocketMQTopicConstant.getSubCredits(), topic)) {
            creditsService.subCredits(SubCreditsMsgDto.decode(message.getBody()));
        } else if (Objects.equals(rocketMQTopicConstant.getNotifyDeveloper(), topic)) {
            creditsService.notifyDeveloper(NotifyDeveloperMsg.decode(message.getBody()));
        } else if (Objects.equals(rocketMQTopicConstant.getAddCredits(), topic)) {
            creditsService.addCredits(AddCreditsMsgDto.decode(message.getBody()));
        }else if(Objects.equals(rocketMQTopicConstant.getVirtualExchange(), topic)){
            creditsService.virtualExchange(VirtualMsgDto.decode(message.getBody()));
        } else if (Objects.equals(rocketMQTopicConstant.getValidatePrizeTag(), topic)) {
            devAppTrustConfService.sendDevPrizeTagMsg(ValidatePrizeTagMsg.decode(message.getBody()));
        } else if (Objects.equals(rocketMQTopicConstant.getSendEmail(), topic)) {
            emailService.sendEmail(EmailMsg.decode(message.getBody()));
        } else if (Objects.equals(rocketMQTopicConstant.getNotifyQueue(), topic)) {
            doNotify(message);
        } else if(Objects.equals(rocketMQTopicConstant.getDingMessage(), topic)){
            sendDingMsgHelper.handleMqMessage(message);
        } else if(Objects.equals(rocketMQTopicConstant.getDelayMsg(), topic)) {
            String body = new String(message.getBody(), Charset.forName("utf-8"));
            NotifyQueueDO notifyQueueDO = JSONObject.parseObject(body, NotifyQueueDO.class);
            creditsService.delayMsgNotify(notifyQueueDO);
        } else {
            logger.warn("暂不应该有其他topic被消费, topic:{}, message:{}", topic, message);
            //接口层现在是一条条拿，不是批量拿，所以加return没问题。但要注意如果mq server配置改了，接口层是批量拿会有问题
            isConsumed = false;
        }
        return isConsumed;
    }

    private void doNotify(MessageExt message) {
    	//解析 消息
    	String body = GZIPCompressUtil.ungzip(message.getBody());
		if (StringUtils.isNotBlank(body)) {
			NotifyQueueDto dto = JSONObject.parseObject(body, NotifyQueueDto.class);
			notifyService.notifyFromMq(dto);
		}
	}


}

==> thirdparty-service-biz-1.0.34-sources.jar: cn/com/duiba/mq/RocketMqMessageListener.java <==
package cn.com.duiba.mq;


import cn.com.duiba.api.bo.addcredits.AddCreditsMsgDto;
import cn.com.duiba.api.bo.mq.EmailMsg;
import cn.com.duiba.api.bo.subcredits.SubCreditsMsgDto;
import cn.com.duiba.api.bo.virtual.VirtualMsgDto;
import cn.com.duiba.api.tools.GZIPCompressUtil;
import cn.com.duiba.crecord.message.CrecordAsyncHttp;
import cn.com.duiba.mq.dinghandler.SendDingMsgHelper;
import cn.com.duiba.notifycenter.domain.NotifyQueueDO;
import cn.com.duiba.notifycenter.service.NotifyService;
import cn.com.duiba.service.CreditsService;
import cn.com.duiba.service.DevAppTrustConfService;
import cn.com.duiba.service.EmailService;
import cn.com.duiba.service.impl.DuibaVirtualConsumeManager;
import cn.com.duiba.thirdparty.dto.NotifyQueueDto;
import cn.com.duiba.thirdparty.mq.msg.NotifyDeveloperMsg;
import cn.com.duiba.thirdparty.mq.msg.ValidatePrizeTagMsg;
import com.alibaba.fastjson.JSONObject;
import org.apache.commons.lang.StringUtils;
import org.apache.rocketmq.client.consumer.listener.ConsumeConcurrentlyContext;
import org.apache.rocketmq.client.consumer.listener.ConsumeConcurrentlyStatus;
import org.apache.rocketmq.client.consumer.listener.MessageListenerConcurrently;
import org.apache.rocketmq.common.message.MessageExt;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import java.nio.charset.Charset;
import java.util.List;
import java.util.Objects;

/**
 * Created by yansen on 17/5/5.
 */
@Component("bootRocketMqMessageListener")
public class RocketMqMessageListener implements MessageListenerConcurrently {

    private static Logger logger = LoggerFactory.getLogger(RocketMqMessageListener.class);

    @Autowired
    private DevAppTrustConfService devAppTrustConfService;

    @Autowired
    private RocketMQTopicConstant rocketMQTopicConstant;

    @Autowired
    private CrecordAsyncHttp crecordAsyncHttp;

    @Autowired
    private CreditsService creditsService;
    @Autowired
    private EmailService emailService;
    @Autowired
    private NotifyService notifyService;
    @Autowired
    private SendDingMsgHelper sendDingMsgHelper;
    @Autowired
    private DuibaVirtualConsumeManager duibaVirtualConsumeManager;

    /**
     * It is not recommend to throw exception,rather than returning ConsumeConcurrentlyStatus.RECONSUME_LATER if consumption failure
     *
     * @param msgs    msgs.size() >= 1<br> DefaultMQPushConsumer.consumeMessageBatchMaxSize=1,you can modify here
     * @param context
     * @return The consume status
     */
    @Override
    public ConsumeConcurrentlyStatus consumeMessage(List<org.apache.rocketmq.common.message.MessageExt> msgs, ConsumeConcurrentlyContext context) {
        MessageExt index = null;
        try {
            //经过duiba-spring-boot-starter的内部限制，实际上msgs里只会包含一个消息，但是不排除将来可能会改为多个，而且每个消息的topic都不同
            for (MessageExt message : msgs) {
                if (null == message) {
                    if (null != context && null != context.getMessageQueue()) {
                        logger.info("消费消息异常,message为空 {}", context.getMessageQueue().getTopic());
                    } else {
                        logger.info("消费消息异常,message为空，队列也为空");
                    }
                    continue;
                }
                index = message;
                String topic = message.getTopic();
                if (!consumePerMessage(message, topic)) {
                    return ConsumeConcurrentlyStatus.RECONSUME_LATER;
                }
            }
        } catch (Exception e) {
            logger.error("消费消息异常,topic:{}, msg:{}", index.getTopic(), JSONObject.toJSONString(SubCreditsMsgDto.decode(index.getBody())), e);
            if (e.getCause() != null) {
                logger.error("消费消息异常,cause:{}", e.getCause());
            }
            //发生异常时通常要重新消费，如果在发生特殊异常时你不希望该消息重新消费
            // 则自行加个catch分支，并返回ConsumeConcurrentlyStatus.CONSUME_SUCCESS
            return ConsumeConcurrentlyStatus.RECONSUME_LATER;
        }
        return ConsumeConcurrentlyStatus.CONSUME_SUCCESS;
    }

    private boolean consumePerMessage(MessageExt message, String topic) {
        boolean isConsumed = true;
        //兑换记录同步
        if (Objects.equals(rocketMQTopicConstant.getCrecordRequest(), topic)) {
            String body = new String(message.getBody(), Charset.forName("utf-8"));
            crecordAsyncHttp.asyncSubmit(body);
        } else if (Objects.equals(rocketMQTopicConstant.getSubCredits(), topic)) {
            creditsService.subCredits(SubCreditsMsgDto.decode(message.getBody()));
        } else if (Objects.equals(rocketMQTopicConstant.getNotifyDeveloper(), topic)) {
            creditsService.notifyDeveloper(NotifyDeveloperMsg.decode(message.getBody()));
        } else if (Objects.equals(rocketMQTopicConstant.getAddCredits(), topic)) {
            creditsService.addCredits(AddCreditsMsgDto.decode(message.getBody()));
        } else if (Objects.equals(rocketMQTopicConstant.getVirtualExchange(), topic)) {
            creditsService.virtualExchange(VirtualMsgDto.decode(message.getBody()));
        } else if (Objects.equals(rocketMQTopicConstant.getValidatePrizeTag(), topic)) {
            devAppTrustConfService.sendDevPrizeTagMsg(ValidatePrizeTagMsg.decode(message.getBody()));
        } else if (Objects.equals(rocketMQTopicConstant.getSendEmail(), topic)) {
            emailService.sendEmail(EmailMsg.decode(message.getBody()));
        } else if (Objects.equals(rocketMQTopicConstant.getNotifyQueue(), topic)) {
            doNotify(message);
        } else if (Objects.equals(rocketMQTopicConstant.getDingMessage(), topic)) {
            sendDingMsgHelper.handleMqMessage(message);
        } else if (Objects.equals(rocketMQTopicConstant.getDelayMsg(), topic)) {
            String body = new String(message.getBody(), Charset.forName("utf-8"));
            NotifyQueueDO notifyQueueDO = JSONObject.parseObject(body, NotifyQueueDO.class);
            creditsService.delayMsgNotify(notifyQueueDO);
        } else if (Objects.equals(rocketMQTopicConstant.getDuibaDirectChargeVirtualTopic(), topic)) {
            String body = new String(message.getBody(), Charset.forName("utf-8"));
            duibaVirtualConsumeManager.handleMqMessage(body);
        } else {
            logger.warn("暂不应该有其他topic被消费, topic:{}, message:{}", topic, message);
            //接口层现在是一条条拿，不是批量拿，所以加return没问题。但要注意如果mq server配置改了，接口层是批量拿会有问题
            isConsumed = false;
        }
        return isConsumed;
    }

    private void doNotify(MessageExt message) {
        //解析 消息
        String body = GZIPCompressUtil.ungzip(message.getBody());
        if (StringUtils.isNotBlank(body)) {
            NotifyQueueDto dto = JSONObject.parseObject(body, NotifyQueueDto.class);
            notifyService.notifyFromMq(dto);
        }
    }


}
